import molspecutils.alchemy.meta as meta
from attrs import asdict
from molspecutils.happier import CO2_llq_to_pair, CO2GlobalState, HITRANRow
from sqlalchemy import (Column, Float, Integer, MetaData, Table)


def state_dicts(row: HITRANRow):
    """Return state dicts for insertion into db."""
    jpp, jp = CO2_llq_to_pair(row.llq)

    statepp = asdict(CO2GlobalState.from_str(row.glq))
    statepp.update({'g': row.gpp,
                    'energy': row.elower,
                    'J': jpp})

    statep = asdict(CO2GlobalState.from_str(row.guq))
    statep.update({'g': row.gp,
                   'energy': row.elower+row.nu,
                   'J': jp})

    return statepp, statep


def skip_func(statepp: dict, statep: dict) -> bool:
    nus = ['nu1', 'nu2', 'l2']
    pp = [statepp[nu]==0 for nu in nus] + [statepp['r']==1]
    p = [statep[nu]==0 for nu in nus] + [statep['r']==1]

    return not all(pp + p)

metadata = MetaData()

states = Table(
    "states", metadata,
    Column('id', Integer, primary_key=True),
    Column('energy', Float),    # general
    Column('g', Float),
    Column('J', Integer),     # rotational

    Column('nu1', Integer),   # vibrational
    Column('nu2', Integer),
    Column('nu3', Integer),
    Column('l2', Integer),
    Column('r', Integer)
)

line_parameters = meta.line_parameters.to_metadata(metadata)
